PooledClientGuard

Struct PooledClientGuard 

pub struct PooledClientGuard { /* private fields */ }
Guard that returns a client to the pool when dropped

Implementations

Source

impl PooledClientGuard

pub fn client(&self) -> &dyn LLMClient

Get a reference to the underlying client

pub fn client_mut(&mut self) -> &mut dyn LLMClient

Get a mutable reference to the underlying client

pub fn take(self) -> Box<dyn LLMClient>

Take ownership of the client, preventing it from being returned to the pool

This is useful if you need to move the client elsewhere, but be aware that it won’t be returned to the pool.